/*******************************************************************
 *
 * Copyright  1998, Bachmann Software and Services.
 * All rights reserved.
 *
 * FileName:
 *		PrintMgrDefines.h
 *
 * Description:
 *		Print Manager library private definitions.
 *
 * History:
 *   	03/30/99    Greg Winton    Created file.
 *
 *   	04/07/99    Greg Winton    Added PagFontType declaration.
 *
 *******************************************************************/

#ifndef __PAGE_MGR_DEFINES_H__
#define __PAGE_MGR_DEFINES_H__

// PalmPilot common definitions
#include <Common.h>

/********************************************************************
 * Type and creator of Sample Library database
 ********************************************************************/
#define  pageMgrCreatorID  'BPGM'               // Bachmann Page Manager database creator
#define  pageMgrTypeID     'libr'               // Standard library database type

/********************************************************************
 * Internal library name which can be passed to SysLibFind()
 ********************************************************************/
#define		pageMgrName			"PageMgr"

/************************************************************
 * PageMgr Library result codes
 * (appErrorClass is reserved for 3rd party apps/libraries.
 * It is defined in SystemMgr.h)
 *************************************************************/

#define pagErrParam			(appErrorClass | 1)		// invalid parameter
#define pagErrNotOpen		(appErrorClass | 2)		// library is not open
#define pagErrAlreadyOpen  (appErrorClass | 3)     // return from PagOpen() if
                                                   // the library is already open by others
#define pagErrStillOpen		(appErrorClass | 4)		// returned from PagClose() if
																	// the library is still open by others
#define pagErrMemory			(appErrorClass | 5)		// memory error occurred
#define pagErrDevice       (appErrorClass | 6)     // device not ready error
#define pagErrPort         (appErrorClass | 7)     // port error occurred
#define pagErrAbort        (appErrorClass | 8)     // user aborted
#define pagErrNotImpl      (appErrorClass | 9)     // function not implemented
#define pagErrNotSupp      (appErrorClass | 10)    // request not supported.
#define pagErrState        (appErrorClass | 11)    // state error
#define pagErrNoConfig     (appErrorClass | 12)    // BPM Config needs to be run to set a default device

/********************************************************************
 * Option Defines
 ********************************************************************/
typedef enum {
   pagOptionMaxLines
} PagOptionEnum;

// Max font typeface length.
#define pagFontMaxTypeface (25)

typedef struct {
   Char           typeface [pagFontMaxTypeface+1];
   UInt           height;
   Boolean        bold;
   Boolean        italics;
   } PagFontType;

typedef PagFontType* PagFontPtr;

/********************************************************************
 * Public Structures
 ********************************************************************/

#define  MAXSIZE_DRIVERNAME         25


#endif	// __PAGE_MGR_DEFINES_H__
